/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM flockIRichDNDService.idl
 */

#ifndef __gen_flockIRichDNDService_h__
#define __gen_flockIRichDNDService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsITransferable_h__
#include "nsITransferable.h"
#endif

#ifndef __gen_nsIDragSession_h__
#include "nsIDragSession.h"
#endif

#ifndef __gen_nsIDOMHTMLElement_h__
#include "nsIDOMHTMLElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    flockIMessage */
#define FLOCKIMESSAGE_IID_STR "a6204395-ab6e-43f0-8bed-29afd826b1e8"

#define FLOCKIMESSAGE_IID \
  {0xa6204395, 0xab6e, 0x43f0, \
    { 0x8b, 0xed, 0x29, 0xaf, 0xd8, 0x26, 0xb1, 0xe8 }}

/**
 * Interface for passing messages ready to be posted or shared via a service
 *
 * @see flockIRichDNDService#getMessageFromTransferable
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockIMessage : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIMESSAGE_IID)

  /* attribute AString subject; */
  NS_SCRIPTABLE NS_IMETHOD GetSubject(nsAString & aSubject) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetSubject(const nsAString & aSubject) = 0;

  /* attribute AString body; */
  NS_SCRIPTABLE NS_IMETHOD GetBody(nsAString & aBody) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetBody(const nsAString & aBody) = 0;

  /* attribute AString htmlbody; */
  NS_SCRIPTABLE NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIMessage, FLOCKIMESSAGE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIMESSAGE \
  NS_SCRIPTABLE NS_IMETHOD GetSubject(nsAString & aSubject); \
  NS_SCRIPTABLE NS_IMETHOD SetSubject(const nsAString & aSubject); \
  NS_SCRIPTABLE NS_IMETHOD GetBody(nsAString & aBody); \
  NS_SCRIPTABLE NS_IMETHOD SetBody(const nsAString & aBody); \
  NS_SCRIPTABLE NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody); \
  NS_SCRIPTABLE NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIMESSAGE(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetSubject(nsAString & aSubject) { return _to GetSubject(aSubject); } \
  NS_SCRIPTABLE NS_IMETHOD SetSubject(const nsAString & aSubject) { return _to SetSubject(aSubject); } \
  NS_SCRIPTABLE NS_IMETHOD GetBody(nsAString & aBody) { return _to GetBody(aBody); } \
  NS_SCRIPTABLE NS_IMETHOD SetBody(const nsAString & aBody) { return _to SetBody(aBody); } \
  NS_SCRIPTABLE NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody) { return _to GetHtmlbody(aHtmlbody); } \
  NS_SCRIPTABLE NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody) { return _to SetHtmlbody(aHtmlbody); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIMESSAGE(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetSubject(nsAString & aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubject(aSubject); } \
  NS_SCRIPTABLE NS_IMETHOD SetSubject(const nsAString & aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSubject(aSubject); } \
  NS_SCRIPTABLE NS_IMETHOD GetBody(nsAString & aBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBody(aBody); } \
  NS_SCRIPTABLE NS_IMETHOD SetBody(const nsAString & aBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBody(aBody); } \
  NS_SCRIPTABLE NS_IMETHOD GetHtmlbody(nsAString & aHtmlbody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHtmlbody(aHtmlbody); } \
  NS_SCRIPTABLE NS_IMETHOD SetHtmlbody(const nsAString & aHtmlbody) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHtmlbody(aHtmlbody); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIMessage
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIMESSAGE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIMessage)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* attribute AString subject; */
NS_IMETHODIMP _MYCLASS_::GetSubject(nsAString & aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetSubject(const nsAString & aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString body; */
NS_IMETHODIMP _MYCLASS_::GetBody(nsAString & aBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetBody(const nsAString & aBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString htmlbody; */
NS_IMETHODIMP _MYCLASS_::GetHtmlbody(nsAString & aHtmlbody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetHtmlbody(const nsAString & aHtmlbody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIRichDNDService */
#define FLOCKIRICHDNDSERVICE_IID_STR "3bf74fbf-2068-4a70-8df6-61526cf8f85d"

#define FLOCKIRICHDNDSERVICE_IID \
  {0x3bf74fbf, 0x2068, 0x4a70, \
    { 0x8d, 0xf6, 0x61, 0x52, 0x6c, 0xf8, 0xf8, 0x5d }}

class NS_NO_VTABLE NS_SCRIPTABLE flockIRichDNDService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIRICHDNDSERVICE_IID)

  /**
   * Adds the given content to the target element in a rich text editor.
   *
   * @param aContent (in) the content to be added
   * @param aTargetElement (in) the target on which we are dropping rich content
   */
  /* void addToRichTextEditor (in AString aContent, in nsIDOMHTMLElement aTargetElement); */
  NS_SCRIPTABLE NS_IMETHOD AddToRichTextEditor(const nsAString & aContent, nsIDOMHTMLElement *aTargetElement) = 0;

  /**
   * Produce a rich nsITransferable from a nsIDragSession. The result
   * is different from what you would get from nsIDragSession.getData(),
   * because we analyse the sourceNode to enrich the resulting
   * nsITransferable. Additional data from the drop may be included to provide
   * more information to the transferable.
   *
   * @param aSession (in) the current drag session
   * @param aDropFlavour (in) the flavour of the drop data
   * @param aDropData (in) the value of the drop data
   * @return a nsITransferable with one or more of the following flavors:
   *         - text/unicode
   *         - text/html
   *         - text/x-moz-url
   *         - text/x-flock-media
   *         - text/x-flock-textcitation
   *         - text/x-flock-htmlcitation
   *
   * text/x-flock-media has the same syntax as text/x-moz-url:
   *    url + "\n" + title
   * we use it to make a distinction with url pointing to webpages, so
   * the caller can treat media data in a different way
   *
   * text/x-flock-{text/html}citation are a represenation of the data
   * plus its source (with title and URL of the source page)
   */
  /* nsITransferable getRichSelection (in nsIDragSession aSession, in AString aDropFlavour, in AString aDropData); */
  NS_SCRIPTABLE NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval) = 0;

  /**
   * Helper method to extract a flockIMessage from an nsITransferable subject
   * Supports several flavours of transferable data:
   *         - text/unicode
   *         - text/html
   *         - text/x-moz-url
   *         - text/x-flock-media
   *         - text/x-flock-textcitation
   *         - text/x-flock-htmlcitation
   *         - moz/rdfitem
   *
   * @param aSubject (in) a nsITransferable
   * @param aListSize (in) the number of elements in the flavor list array
   * @param aFlavorList (in) an array of desired flavors, in order of
   *                         preference. The message is formatted based on the
   *                         first flavor from the list that is supported by the
   *                         transferable. If none are found, it looks for a
   *                         supported flavor in the transferable.
   * @return a flockIMessage object.
   */
  /* flockIMessage getMessageFromTransferable (in nsITransferable aSubject, in unsigned long aListSize, [array, size_is (aListSize)] in string aFlavorList); */
  NS_SCRIPTABLE NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval) = 0;

  /**
   * Returns appropriately formatted breadcrumb.
   *
   * @param aType (in) [optional] one of the following:
   *        - plain (default)
   *        - rich
   */
  /* AString getBreadcrumb (in AString aType); */
  NS_SCRIPTABLE NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval) = 0;

  /**
   * Returns TRUE if the given element contains a breadcrumb.
   *
   * @param aElement (in) the element to inspect for breadcrumb 
   */
  /* boolean hasBreadcrumb (in nsIDOMHTMLElement aElement); */
  NS_SCRIPTABLE NS_IMETHOD HasBreadcrumb(nsIDOMHTMLElement *aElement, PRBool *_retval) = 0;

  /**
   * Determine the appropriate supported service to handle the rich content drop
   * to an element on the page.
   *
   * @param aSession (in) the drag and drop session
   * @param aTargetElement (in) the target on which we are dropping rich content
   * @return TRUE if the drop was handled; else FALSE.
   */
  /* boolean handleDrop (in nsIDragSession aSession, in nsIDOMHTMLElement aTargetElement); */
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) = 0;

  /**
   * Checks if the element is within a rich text editor
   *
   * @param aElement (in) the element to check
   * @return TRUE if the element is within a rich text editor; else FALSE.
   */
  /* boolean isInRichTextEditor (in nsIDOMHTMLElement aElement); */
  NS_SCRIPTABLE NS_IMETHOD IsInRichTextEditor(nsIDOMHTMLElement *aElement, PRBool *_retval) = 0;

  /**
   * Checks if the selection contains rich video content
   *
   * @param aSession (in) the current drag session
   * @return TRUE if the selection contains rich video content; else FALSE.
   */
  /* boolean isSelectionRichVideoContent (in nsIDragSession aSession); */
  NS_SCRIPTABLE NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIRichDNDService, FLOCKIRICHDNDSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIRICHDNDSERVICE \
  NS_SCRIPTABLE NS_IMETHOD AddToRichTextEditor(const nsAString & aContent, nsIDOMHTMLElement *aTargetElement); \
  NS_SCRIPTABLE NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval); \
  NS_SCRIPTABLE NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval); \
  NS_SCRIPTABLE NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval); \
  NS_SCRIPTABLE NS_IMETHOD HasBreadcrumb(nsIDOMHTMLElement *aElement, PRBool *_retval); \
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval); \
  NS_SCRIPTABLE NS_IMETHOD IsInRichTextEditor(nsIDOMHTMLElement *aElement, PRBool *_retval); \
  NS_SCRIPTABLE NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIRICHDNDSERVICE(_to) \
  NS_SCRIPTABLE NS_IMETHOD AddToRichTextEditor(const nsAString & aContent, nsIDOMHTMLElement *aTargetElement) { return _to AddToRichTextEditor(aContent, aTargetElement); } \
  NS_SCRIPTABLE NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval) { return _to GetRichSelection(aSession, aDropFlavour, aDropData, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval) { return _to GetMessageFromTransferable(aSubject, aListSize, aFlavorList, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval) { return _to GetBreadcrumb(aType, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD HasBreadcrumb(nsIDOMHTMLElement *aElement, PRBool *_retval) { return _to HasBreadcrumb(aElement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) { return _to HandleDrop(aSession, aTargetElement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD IsInRichTextEditor(nsIDOMHTMLElement *aElement, PRBool *_retval) { return _to IsInRichTextEditor(aElement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval) { return _to IsSelectionRichVideoContent(aSession, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIRICHDNDSERVICE(_to) \
  NS_SCRIPTABLE NS_IMETHOD AddToRichTextEditor(const nsAString & aContent, nsIDOMHTMLElement *aTargetElement) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddToRichTextEditor(aContent, aTargetElement); } \
  NS_SCRIPTABLE NS_IMETHOD GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRichSelection(aSession, aDropFlavour, aDropData, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageFromTransferable(aSubject, aListSize, aFlavorList, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetBreadcrumb(const nsAString & aType, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBreadcrumb(aType, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD HasBreadcrumb(nsIDOMHTMLElement *aElement, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->HasBreadcrumb(aElement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->HandleDrop(aSession, aTargetElement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD IsInRichTextEditor(nsIDOMHTMLElement *aElement, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsInRichTextEditor(aElement, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsSelectionRichVideoContent(aSession, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIRichDNDService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIRICHDNDSERVICE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIRichDNDService)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void addToRichTextEditor (in AString aContent, in nsIDOMHTMLElement aTargetElement); */
NS_IMETHODIMP _MYCLASS_::AddToRichTextEditor(const nsAString & aContent, nsIDOMHTMLElement *aTargetElement)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsITransferable getRichSelection (in nsIDragSession aSession, in AString aDropFlavour, in AString aDropData); */
NS_IMETHODIMP _MYCLASS_::GetRichSelection(nsIDragSession *aSession, const nsAString & aDropFlavour, const nsAString & aDropData, nsITransferable **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* flockIMessage getMessageFromTransferable (in nsITransferable aSubject, in unsigned long aListSize, [array, size_is (aListSize)] in string aFlavorList); */
NS_IMETHODIMP _MYCLASS_::GetMessageFromTransferable(nsITransferable *aSubject, PRUint32 aListSize, const char **aFlavorList, flockIMessage **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getBreadcrumb (in AString aType); */
NS_IMETHODIMP _MYCLASS_::GetBreadcrumb(const nsAString & aType, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean hasBreadcrumb (in nsIDOMHTMLElement aElement); */
NS_IMETHODIMP _MYCLASS_::HasBreadcrumb(nsIDOMHTMLElement *aElement, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean handleDrop (in nsIDragSession aSession, in nsIDOMHTMLElement aTargetElement); */
NS_IMETHODIMP _MYCLASS_::HandleDrop(nsIDragSession *aSession, nsIDOMHTMLElement *aTargetElement, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isInRichTextEditor (in nsIDOMHTMLElement aElement); */
NS_IMETHODIMP _MYCLASS_::IsInRichTextEditor(nsIDOMHTMLElement *aElement, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isSelectionRichVideoContent (in nsIDragSession aSession); */
NS_IMETHODIMP _MYCLASS_::IsSelectionRichVideoContent(nsIDragSession *aSession, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockIRichContentDropHandler */
#define FLOCKIRICHCONTENTDROPHANDLER_IID_STR "a365b092-97bf-43ca-ab7d-1c713fc8f5f8"

#define FLOCKIRICHCONTENTDROPHANDLER_IID \
  {0xa365b092, 0x97bf, 0x43ca, \
    { 0xab, 0x7d, 0x1c, 0x71, 0x3f, 0xc8, 0xf5, 0xf8 }}

class NS_NO_VTABLE NS_SCRIPTABLE flockIRichContentDropHandler : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKIRICHCONTENTDROPHANDLER_IID)

  /**
   * Handle the rich content drop
   *
   * @param aFlavours (in) use to determine type of content
   * @param aTargetElement (in) the target on which we are dropping rich content
   * @return TRUE if the component handled the drop; else FALSE.
   */
  /* boolean handleDrop (in nsITransferable aFlavours, in nsIDOMHTMLElement aTargetElement); */
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockIRichContentDropHandler, FLOCKIRICHCONTENTDROPHANDLER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKIRICHCONTENTDROPHANDLER \
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLElement *aTargetElement, PRBool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKIRICHCONTENTDROPHANDLER(_to) \
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) { return _to HandleDrop(aFlavours, aTargetElement, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKIRICHCONTENTDROPHANDLER(_to) \
  NS_SCRIPTABLE NS_IMETHOD HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLElement *aTargetElement, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->HandleDrop(aFlavours, aTargetElement, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockIRichContentDropHandler
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKIRICHCONTENTDROPHANDLER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockIRichContentDropHandler)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* boolean handleDrop (in nsITransferable aFlavours, in nsIDOMHTMLElement aTargetElement); */
NS_IMETHODIMP _MYCLASS_::HandleDrop(nsITransferable *aFlavours, nsIDOMHTMLElement *aTargetElement, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_flockIRichDNDService_h__ */
